Skip to content
Navigation Menu
Sign in
Appearance settings
Platform
AI CODE CREATION
GitHub Copilot
Write better code with AI
GitHub Copilot app
Direct agents from issue to merge
MCP Registry
Integrate external tools
DEVELOPER WORKFLOWS
Actions
Automate any workflow
Codespaces
Instant dev environments
Issues
Plan and track work
Code Review
Manage code changes
Code Quality
Enforce quality at merge
APPLICATION SECURITY
GitHub Advanced Security
Find and fix vulnerabilities
Code security
Secure your code as you build
Secret protection
Stop leaks before they start
EXPLORE
Why GitHub
Documentation
Blog
Changelog
Marketplace
View all features
Solutions
BY COMPANY SIZE
Enterprises
Small and medium teams
Startups
Nonprofits
BY USE CASE
App Modernization
DevSecOps
DevOps
CI/CD
View all use cases
BY INDUSTRY
Healthcare
Financial services
Manufacturing
Government
View all industries
View all solutions
Resources
EXPLORE BY TOPIC
AI
Software Development
DevOps
Security
View all topics
EXPLORE BY TYPE
Customer stories
Events & webinars
Ebooks & reports
Business insights
GitHub Skills
SUPPORT & SERVICES
Documentation
Customer support
Community forum
Trust center
Partners
View all resources
Open Source
COMMUNITY
GitHub Sponsors
Fund open source developers
PROGRAMS
Security Lab
Maintainer Community
GitHub Stars
Archive Program
REPOSITORIES
Topics
Trending
Collections
Enterprise
ENTERPRISE SOLUTIONS
Enterprise platform
AI-powered developer platform
AVAILABLE ADD-ONS
GitHub Advanced Security
Enterprise-grade security features
Copilot for Business
Enterprise-grade AI features
Premium Support
Enterprise-grade 24/7 support
Pricing
Search
/
Sign in
Sign up
Appearance settings
You signed in with another tab or window.
Reload
to refresh your session.
You signed out in another tab or window.
Reload
to refresh your session.
You switched accounts on another tab or window.
Reload
to refresh your session.
Dismiss alert
{{ message }}
Uh oh!
There was an error while loading.
Please reload this page
.
clij
/
clij2-plugin-template
Public template
Notifications
You must be signed in to change notification settings
Fork
2
Star
1
Code
Issues
0
Pull requests
0
Actions
Projects
Security and quality
0
Insights
Additional navigation options
Code
Issues
Pull requests
Actions
Projects
Security and quality
Insights
Files
Expand file tree
master
Breadcrumbs
clij2-plugin-template
/
src
/
main
/
java
/
com
/
yourdomain
/
clijplugin
/
template.cl
Copy path
Blame
More file actions
Blame
More file actions
Latest commit
History
History
History
28 lines (24 loc) · 1.19 KB
master
Breadcrumbs
clij2-plugin-template
/
src
/
main
/
java
/
com
/
yourdomain
/
clijplugin
/
template.cl
Copy path
Top
File metadata and controls
Code
Blame
28 lines (24 loc) · 1.19 KB
Raw
Copy raw file
Download raw file
Open symbols panel
Edit and raw actions
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
// todo: Enter your OpenCL code here, rename the .cl file or generate an own .cl file.
//
// Use the method place holders READ_IMAGE to read from an input image.
// Use the method place holders WRITE_IMAGE to write to an ouput image.
// Mark your images as input images using the type place holders IMAGE_src_TYPE where 'src' stands for your variable name.
// To read the image size for within an OpenCL method, use the method place holders GET_IMAGE_WIDTH,
// GET_IMAGE_HEIGHT and GET_IMAGE_DEPTH.
// You find more details on these convenience place holders online: https://github.com/clEsperanto/clij-opencl-kernels
//
__constant sampler_t sampler = CLK_NORMALIZED_COORDS_FALSE | CLK_ADDRESS_CLAMP_TO_EDGE | CLK_FILTER_NEAREST;
__kernel void add_scalar(
IMAGE_src_TYPE src,
IMAGE_dst_TYPE dst,
float scalar
)
{
const int x = get_global_id(0);
const int y = get_global_id(1);
const int z = get_global_id(2);
const POS_src_TYPE source_position = POS_src_INSTANCE(x,y,z,0);
const float value = READ_IMAGE(src, sampler, source_position).x + scalar;
const POS_dst_TYPE destination_position = POS_dst_INSTANCE(x,y,z,0);
WRITE_IMAGE (dst, destination_position, CONVERT_dst_PIXEL_TYPE(value));
}
You can’t perform that action at this time.